function [] = printfigure(filename, varargin)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Print Figure
% 
% The function prints the current figure.
%
% Input Variables:
%       filename  : name for exported file
%   varargin:
%           printit    : export to .png and .fig
%           filename   : name for exported file
%           varargin   : more options for plotdata (see help plotdata for
%                         more information)
%           size       : Size in px [width hight]
%           figHandle  : Handle to figure (default gcf)
%           scaleaxis      : Resize axis
% 11.05.2012 Rasmus Cornelius - IHF - RWTH Aachen
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Default values
folder     = '.';           % Current directory
format     = '-dpng';       % PNG
resolution = '-r300';       % 150dpi
size       = [1500 1000];   % 1400x1000 Pixel

lv = length(varargin);
setpublish = 0;
writeeps = 0;
%ScaleAxis = [-1 0 1 0; 0 -1 0 1; 0 0 1 0; 0 0 0 1];
%ScaleAxis = [];
for i=1:lv
    if ischar(varargin{i})
        switch lower(varargin{i})
            case 'folder'
                folder = varargin{i+1};
            case 'format'
                format = varargin{i+1};
            case 'resolution'
                resolution = varargin{i+1};
            case 'size'
                size = varargin{i+1};
            case 'fighandle'
                %Set GCF
                figure(varargin{i+1});
            case 'scaleaxis'
                ScaleAxis = varargin{i+1};
            case 'publish'
                setpublish = 1;
            case 'eps'
                if exist('epswrite') > 0
                    writeeps = 1;
                else
                    %EPS toolbox allows embedding of fonts.
                    %http://www.mathworks.com/matlabcentral/fileexchange/35429-eps-utility-toolbox
                    error('To write EPS images install eps toolbox');
                end
        end
    end
end

figHandle = gcf;

figAxes = get(figHandle,'CurrentAxes');

if setpublish == 1
    hLines = findobj(gca);
    for k = 1:length(hLines)
        set(hLines(k),'LineWidth',3);
    end
    %set(figAxes,'LineWidth',3,'GridLineStyle', ':'); %FIXME maybe get these values from plotproperties?
    drawnow();
end

set(figHandle,'Position',[0 0 size]);
%set(figHandle,'PaperSize',[]
set(figHandle,'PaperPositionMode','auto')

if ~exist('ScaleAxis','var')
    set(figAxes, 'Position', get(figAxes, 'OuterPosition') - ...
        get(figAxes, 'TightInset') * [-1.5 0 2 0; 0 -1.5 0 1.5; 0 0 2 0; 0 0 0 2]);
else
    set(figAxes,'Position',ScaleAxis);
end



drawnow();
oldFolder = cd(folder);
set(figHandle,'Position',[0 0 size]);

drawnow();
print(figHandle, format ,resolution, [filename '.png']); % Export as picture
%hgsave(figHandle,filename)                % Export as ofig
if writeeps == 1
    epswrite(figHandle,filename,'resolution',resolution,'EmbedFonts','AddSymbol');
end
cd(oldFolder);

end